/*
 * FILE:
 * interface.h
 *
 * FUNCTION:
 * Define the top-most DWI application structure.
 *
 * HISTORY:
 * Linas Vepstas March 2002
 */

#ifndef DUI_INTERFACE_H
#define DUI_INTERFACE_H

#include <glib-object.h>


typedef struct DuiAction_s    DuiAction;
typedef struct DuiDatabase_s  DuiDatabase;
typedef struct DuiFilter_s    DuiFilter;
typedef struct DuiInterface_s DuiInterface;
typedef struct DuiReport_s    DuiReport;
typedef struct DuiSignal_s    DuiSignal;
typedef struct DuiWindow_s    DuiWindow;

DuiInterface * dui_interface_new (void);
void dui_interface_destroy (DuiInterface *dui);

void dui_interfaced_set_name (DuiInterface *dui, const char * name);

/* This call will start making gui calls, and must be called only
 * after glade and gtk have been initialized.  The second argument,
 * "fatal_if_no_main", indicates whether or not its a fatal error
 * if no main wiindow was found.
 */
void dui_interface_realize (DuiInterface *, int fatal_if_no_main);

/* Scan the list of reports in this interface, and return the one with the 
 * indicated name 
 */
DuiAction * dui_interface_find_action_by_name (DuiInterface *, const char * name);
DuiDatabase * dui_interface_find_database_by_name (DuiInterface *, const char * name);
DuiReport * dui_interface_find_report_by_name (DuiInterface *, const char * name);
DuiWindow * dui_interface_find_window_by_name (DuiInterface *, const char * name);

/* Insert a key-value pair into a hash table associated with this
 * interface. */
void dui_interface_kvp_insert (DuiInterface *, const char * key, 
                                             const char * value);

/* Fetch the value assoicated with the key in the hash table */
const char * dui_interface_kvp_lookup (DuiInterface *, const char * key);


void dui_interface_add_action (DuiInterface *, DuiAction *);
void dui_interface_add_database (DuiInterface *, DuiDatabase *);
void dui_interface_add_report (DuiInterface *, DuiReport *);
void dui_interface_add_window (DuiInterface *, DuiWindow *);

void dui_interface_add_object (DuiInterface *, const char * instance_name, GObject *);
GObject * dui_interface_find_object_by_name (DuiInterface *dui, const char *instance_name);
		  

#endif /* DUI_INTERFACE_H */

